<?php

//Include the common file
require_once('common.php');

//Check if the user is logged in
if ($authentication->logged_in()) header("Location: index.php");

//Check if the form has been submitted
if (isset($_POST['login'])) {
	
	$validate->email($_POST['email'], 'Email address not valid.');
	$validate->required($_POST['password'], 'Enter your password.');

	if (!$error->has_errors()) {

		$remember = false;
		
		if (isset($_POST['remember']))
			$remember = true;					
			
		if ($authentication->login($_POST['email'], $_POST['password'], $remember))
			header("Location: index.php");
		else
			$failed = true;
		
	} else {
		
		$failed = true;

	}
	
}

//Check if the form has been submitted
if (isset($_POST['reset_password'])) {

	$validate->email($_POST['email'], 'Email address not valid.');
	
	if (!$error->has_errors()) {
		
		if ($authentication->new_password($_POST['email']))
			$success = true;
		else
			$failed = true;
			
	}
				
}
			
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	
<!-- BEGIN head -->	
<head>
	
	<!-- Meta Tags -->
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> 
	
	<!-- Title -->
	<title>Authentication System</title>

	<!-- Style sheet -->
	<link href="css/style.css" rel="stylesheet" type="text/css" />
	<link href="css/reset.css" rel="stylesheet" type="text/css" />
	<link href="css/text.css" rel="stylesheet" type="text/css" />
	<link href="css/960.css" rel="stylesheet" type="text/css" />
	<link href="css/jquery.qtip.min.css" rel="stylesheet" type="text/css" />

	<!-- jQuery -->
	<script type="text/javascript" src="js/jquery.min.js"></script>
	<!-- jQuery plugins -->
	<script type="text/javascript" src="js/jquery.validate.min.js"></script>
	<script type="text/javascript" src="js/jquery.qtip.min.js"></script>

	<script type="text/javascript">
	// <![CDATA[
	$(document).ready(function() {

		//qTip
		$('a[title], img[title], span[title]').qtip({
			style: {
				classes: 'ui-tooltip-shadow ui-tooltip-plain'
			},
			position: {
				my: 'bottom center',
				at: 'top center'
			}
		});
				
		//Check form fields
		$("form#login").validate({
			rules: {
				email: {
					required: true,
					email: true
				},
				password: "required"
			},
			messages: {
				email: {
					required: "Enter your email address.", 
					email: "Email address not valid."
				},
				password: "Enter your password."
			},
			success: function(label) {
				label.html("&nbsp;").addClass("success");
			}
		});

		//Check form fields
		$("form#password_forgotten").validate({
			rules: {
				email: {
					required: true,
					email: true
				}
			},
			messages: {
				email: {
					required: "Enter your email address.", 
					email: "Email address not valid."
				}
			},
			success: function(label) {
				label.html("&nbsp;").addClass("success");
			}
		});
						
	});
	// ]]>
	</script>
				
</head>
<!-- END head -->

<!-- BEGIN body -->
<body>

<!-- BEGIN #wrapper -->
<div id="wrapper">

	<?php if (is_dir(realpath(dirname(__FILE__)) . '/install')): ?>
		<div class="container_12">
			<div class="grid_12 alert error">
				<span>
					<strong>Warning</strong>
				</span>	
				<p>Install folder still exists and should be deleted for security reasons.</p>
			</div>
			<div class="clear"></div>
		</div>
	<?php endif; ?>

	<noscript>
		<div class="container_12">
			<div class="grid_12 alert error">
				<span>
					<strong>Warning</strong>
				</span>	
				<p>
					Many features on the web site require Javascript and cookies, you can enable both via your browser's
					preference settings.
				</p>
			</div>
			<div class="clear"></div>
		</div>
	</noscript>

	<!-- BEGIN #main -->
	<div id="main" class="container_12">
				
		<!-- BEGIN .grid_12 -->
		<div class="grid_12">

			<!-- BEGIN .title_background -->
			<div class="title_background">
				<h1>Login</h1>
			</div>
			<!-- END .title_background -->
					
			<?php if ($error->has_errors()): ?>
			
				<div class="alert error">
					<span>
						<strong>An error occurred while processing request</strong>
					</span>
					<?php foreach ($error->display_errors() as $value): ?>		
						<p><?php echo $value; ?></p>
					<?php endforeach; ?>
				</div>
			
			<?php $error->clear_errors(); endif; ?>

			<?php if (isset($failed) && isset($_POST['login'])): ?>
				<div class="alert error">
					<span>
						<strong>An error occurred while processing request</strong>
					</span>	
					<p>Login failed!</p>
				</div>
			<?php endif; ?>

			<?php if (isset($failed) && isset($_POST['reset_password'])): ?>
				<div class="alert error">
					<span>
						<strong>An error occurred while processing request</strong>
					</span>	
					<p>The email address was not found in our records, please try again!</p>
				</div>
			<?php endif; ?>

			<?php if (isset($success) && isset($_POST['reset_password'])): ?>
				<div class="alert success">
					<p>
						<span>A new password has been sent to your email address!</span>
					</p>
				</div>
			<?php endif; ?>
									
			<form action="" id="login" method="post">
			
				<p>
					<label>Email address: <span title="Required field">*</span></label>
					<input type="text" id="email" name="email" size="50" />
				</p>

				<p>
					<label>Password: <span title="Required field">*</span></label>
					<input type="password" id="password" name="password" size="50" />
				</p>

				<p>
					<label>Remember me</label>
					<input type="checkbox" id="remember" name="remember" value="remember" />
				</p>
									
				<p>
					<button type="submit" name="login" class="button orange">Login now</button>
					<a href="create_account.php" class="button orange">Create account</a>
				</p>
										
			</form>
												
		</div>
		<!-- END .grid_12 -->
		
		<div class="clear">&nbsp;</div>

		<!-- BEGIN .grid_12 -->
		<div class="grid_12">

			<!-- BEGIN .title_background -->
			<div class="title_background">
				<h1>Lost password</h1>
			</div>
			<!-- END .title_background -->
		
			<form action="" id="password_forgotten" method="post">
			
				<p>
					If you've forgotten your password, enter your email address below and we'll send 
					you an email message containing your new password.
				</p>
				
				<p>
					<label>Email address: <span title="Required field">*</span></label>
					<input type="text" id="email" name="email" size="50" />
				</p>
									
				<p>
					<button type="submit" name="reset_password" class="button orange">Submit request</button>
				</p>
			
			</form>
			
		</div>
		<!-- END .grid_12 -->
						
		<div class="clear">&nbsp;</div>
				
	</div>
	<!-- END #main -->

</div>
<!-- END #wrapper -->

<!-- BEGIN .container_12 -->
<div class="container_12">
	
	<!-- BEGIN #footer -->
	<div id="footer" class="grid_12 text_center">
		<p>Copyright &copy; 2012 Gnt Studio - Download <a href="http://www.persianscript.ir">PersianScript</a></p>
	</div>
	<!-- END #footer -->
	
	<div class="clear">&nbsp;</div>
	
</div>
<!-- END .container_12 -->
			
</body>
<!-- END body -->

</html>
