<?php

//Include the common file
require_once('common.php');

//Check if the user is logged in
if (!$authentication->logged_in()) header("Location: login.php");

//User details
$user = $authentication->get_user($session->get('user_id'));

//Check if the form has been submitted
if (isset($_POST['submit'])) {
	
	$validate->required($_POST['first_name'], 'Enter your first name.');
	$validate->required($_POST['last_name'], 'Enter your last name.');
	$validate->required($_POST['password'], 'Enter your password.');
	$validate->matches($_POST['password'], $_POST['confirm_password'], 'The password field does not match the confirm password field.');

	if (!$error->has_errors()) {

		$additional_data = array(
			'first_name' 	=> $_POST['first_name'],
			'last_name' 	=> $_POST['last_name']
		);
		
		$authentication->update_user($session->get('user_id'), $user['user_email'], $_POST['password'], $additional_data);

		$success = true;
				
	}
	
}
			
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	
<!-- BEGIN head -->	
<head>
	
	<!-- Meta Tags -->
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> 
	
	<!-- Title -->
	<title>Authentication System</title>

	<!-- Style sheet -->
	<link href="css/style.css" rel="stylesheet" type="text/css" />
	<link href="css/reset.css" rel="stylesheet" type="text/css" />
	<link href="css/text.css" rel="stylesheet" type="text/css" />
	<link href="css/960.css" rel="stylesheet" type="text/css" />
	<link href="css/jquery.qtip.min.css" rel="stylesheet" type="text/css" />

	<!-- jQuery -->
	<script type="text/javascript" src="js/jquery.min.js"></script>
	<!-- jQuery plugins -->
	<script type="text/javascript" src="js/jquery.validate.min.js"></script>
	<script type="text/javascript" src="js/jquery.qtip.min.js"></script>

	<script type="text/javascript">
	// <![CDATA[
	$(document).ready(function() {

		//qTip
		$('a[title], img[title], span[title]').qtip({
			style: {
				classes: 'ui-tooltip-shadow ui-tooltip-plain'
			},
			position: {
				my: 'bottom center',
				at: 'top center'
			}
		});

		//Check form fields
		$("form#edit_account").validate({
			rules: {
				first_name: "required",
				last_name: "required",
				password: "required",
				confirm_password: {
					required: true,
					equalTo: "#password"
				}
			},
			messages: {
				first_name: "Enter your first name.",
				last_name: "Enter your last name.",
				password: "Enter your password.",
				confirm_password: {
					required: "Confirm your password.", 
					equalTo: "The password does not match."
				}
			},
			success: function(label) {
				label.html("&nbsp;").addClass("success");
			}
		});
							
	});
	// ]]>
	</script>
				
</head>
<!-- END head -->

<!-- BEGIN body -->
<body>

<!-- BEGIN #wrapper -->
<div id="wrapper">

	<?php if (is_dir(realpath(dirname(__FILE__)) . '/install')): ?>
		<div class="container_12">
			<div class="grid_12 alert error">
				<span>
					<strong>Warning</strong>
				</span>	
				<p>Install folder still exists and should be deleted for security reasons.</p>
			</div>
			<div class="clear"></div>
		</div>
	<?php endif; ?>

	<noscript>
		<div class="container_12">
			<div class="grid_12 alert error">
				<span>
					<strong>Warning</strong>
				</span>	
				<p>
					Many features on the web site require Javascript and cookies, you can enable both via your browser's
					preference settings.
				</p>
			</div>
			<div class="clear"></div>
		</div>
	</noscript>

	<!-- BEGIN #main -->
	<div id="main" class="container_12">

		<!-- BEGIN .grid_12 -->
		<div class="grid_12">
			
			<?php if (isset($success)): ?>
				<div class="alert success">
					<p>
						<span>User edited successfully!</span>
					</p>
				</div>
			<?php endif; ?>
						
			<?php if ($error->has_errors()): ?>
			
				<div class="alert error">
					<span>
						<strong>An error occurred while processing request</strong>
					</span>
					<?php foreach ($error->display_errors() as $value): ?>		
						<p><?php echo $value; ?></p>
					<?php endforeach; ?>
				</div>
			
			<?php $error->clear_errors(); endif; ?>
			
			<form action="" id="edit_account" method="post">
				
				<div class="title_background">
					<h1>Your personal details</h1>
				</div>
				
				<p>
					<label><?php echo $user['first_name']; ?> <?php echo $user['last_name']; ?>:</label>
					<a href="http://gravatar.com/emails/" target="_blank">
						<img src="<?php echo get_gravatar($user['user_email'], 48, config_item('authentication', 'site_url') . 'images/gravatar_48.png'); ?>" alt="" title="Change your avatar at gravatar.com" class="gravatar" />
					</a>
				</p>
				
				<p>
					<label>First name: <span title="Required field">*</span></label>
					<input type="text" id="first_name" name="first_name" size="50" value="<?php echo $user['first_name']; ?>" />
				</p>
			
				<p>
					<label>Last name: <span title="Required field">*</span></label>
					<input type="text" id="last_name" name="last_name" size="50" value="<?php echo $user['last_name']; ?>" />
				</p>
			
				<p>
					<label>Email address: <span title="Required field">*</span></label>
					<input type="text" id="email" name="email" size="50" value="<?php echo $user['user_email']; ?>" readonly="readonly" />
				</p>
				
				<p>
					<label>Password: <span title="Required field">*</span></label>
					<input type="password" id="password" name="password" size="50" />
				</p>
									
				<p>
					<label>Confirm password: <span title="Required field">*</span></label>
					<input type="password" id="confirm_password" name="confirm_password" size="50" />
				</p>
				
				<p>
					<button type="submit" name="submit" class="button orange">Edit account</button>
					<a href="?logout" class="button orange">Logout</a>
				</p>
																		
			</form>
													
		</div>
		<!-- END .grid_12 -->
		
		<div class="clear">&nbsp;</div>
				
	</div>
	<!-- END #main -->

</div>
<!-- END #wrapper -->

<!-- BEGIN .container_12 -->
<div class="container_12">
	
	<!-- BEGIN #footer -->
	<div id="footer" class="grid_12 text_center">
		<p>Copyright &copy; 2012 Gnt Studio</p>
	</div>
	<!-- END #footer -->
	
	<div class="clear">&nbsp;</div>
	
</div>
<!-- END .container_12 -->
			
</body>
<!-- END body -->

</html>
